# Answering Questions about the MAIL Protocol

This directory contains Markdown documents dedicated to answering specific questions people might have about the Multi-Agent Interface Layer (MAIL) protocol.

Specifically, it contains reasoning and justifications behind certain protocol tidbits or quirks that may otherwise seem inconsistent or counterintuitive.

This section is by no means complete, and probably never will be. If you have questions about the MAIL protocol that aren't answered here, feel free to ask on GitHub. Otherwise, if you have a good answer to a question that is not currently listed (but should be), feel free to add it.

-Addison